==> hapi-fhir-structures-r4-3.3.0-sources.jar: org/hl7/fhir/r4/model/codesystems/GenderIdentity.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sat, Mar 3, 2018 18:00-0500 for FHIR v3.2.0


import org.hl7.fhir.exceptions.FHIRException;

public enum GenderIdentity {

        /**
         * the patient identifies as transgender male-to-female
         */
        TRANSGENDERFEMALE, 
        /**
         * the patient identifies as transgender female-to-male
         */
        TRANSGENDERMALE, 
        /**
         * the patient identifies with neither/both female and male
         */
        NONBINARY, 
        /**
         * the patient identifies as male
         */
        MALE, 
        /**
         * the patient identifies as female
         */
        FEMALE, 
        /**
         * other gender identity
         */
        OTHER, 
        /**
         * the patient does not wish to disclose his gender identity
         */
        NONDISCLOSE, 
        /**
         * added to help the parsers
         */
        NULL;
        public static GenderIdentity fromCode(String codeString) throws FHIRException {
            if (codeString == null || "".equals(codeString))
                return null;
        if ("transgender-female".equals(codeString))
          return TRANSGENDERFEMALE;
        if ("transgender-male".equals(codeString))
          return TRANSGENDERMALE;
        if ("non-binary".equals(codeString))
          return NONBINARY;
        if ("male".equals(codeString))
          return MALE;
        if ("female".equals(codeString))
          return FEMALE;
        if ("other".equals(codeString))
          return OTHER;
        if ("non-disclose".equals(codeString))
          return NONDISCLOSE;
        throw new FHIRException("Unknown GenderIdentity code '"+codeString+"'");
        }
        public String toCode() {
          switch (this) {
            case TRANSGENDERFEMALE: return "transgender-female";
            case TRANSGENDERMALE: return "transgender-male";
            case NONBINARY: return "non-binary";
            case MALE: return "male";
            case FEMALE: return "female";
            case OTHER: return "other";
            case NONDISCLOSE: return "non-disclose";
            default: return "?";
          }
        }
        public String getSystem() {
          return "http://hl7.org/fhir/gender-identity";
        }
        public String getDefinition() {
          switch (this) {
            case TRANSGENDERFEMALE: return "the patient identifies as transgender male-to-female";
            case TRANSGENDERMALE: return "the patient identifies as transgender female-to-male";
            case NONBINARY: return "the patient identifies with neither/both female and male";
            case MALE: return "the patient identifies as male";
            case FEMALE: return "the patient identifies as female";
            case OTHER: return "other gender identity";
            case NONDISCLOSE: return "the patient does not wish to disclose his gender identity";
            default: return "?";
          }
        }
        public String getDisplay() {
          switch (this) {
            case TRANSGENDERFEMALE: return "transgender female";
            case TRANSGENDERMALE: return "transgender male";
            case NONBINARY: return "non-binary";
            case MALE: return "male";
            case FEMALE: return "female";
            case OTHER: return "other";
            case NONDISCLOSE: return "does not wish to disclose";
            default: return "?";
          }
    }


}

==> hapi-fhir-structures-r4-3.4.0-sources.jar: org/hl7/fhir/r4/model/codesystems/GenderIdentity.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sun, May 6, 2018 17:51-0400 for FHIR v3.4.0


import org.hl7.fhir.exceptions.FHIRException;

public enum GenderIdentity {

        /**
         * the patient identifies as transgender male-to-female
         */
        TRANSGENDERFEMALE, 
        /**
         * the patient identifies as transgender female-to-male
         */
        TRANSGENDERMALE, 
        /**
         * the patient identifies with neither/both female and male
         */
        NONBINARY, 
        /**
         * the patient identifies as male
         */
        MALE, 
        /**
         * the patient identifies as female
         */
        FEMALE, 
        /**
         * other gender identity
         */
        OTHER, 
        /**
         * the patient does not wish to disclose his gender identity
         */
        NONDISCLOSE, 
        /**
         * added to help the parsers
         */
        NULL;
        public static GenderIdentity fromCode(String codeString) throws FHIRException {
            if (codeString == null || "".equals(codeString))
                return null;
        if ("transgender-female".equals(codeString))
          return TRANSGENDERFEMALE;
        if ("transgender-male".equals(codeString))
          return TRANSGENDERMALE;
        if ("non-binary".equals(codeString))
          return NONBINARY;
        if ("male".equals(codeString))
          return MALE;
        if ("female".equals(codeString))
          return FEMALE;
        if ("other".equals(codeString))
          return OTHER;
        if ("non-disclose".equals(codeString))
          return NONDISCLOSE;
        throw new FHIRException("Unknown GenderIdentity code '"+codeString+"'");
        }
        public String toCode() {
          switch (this) {
            case TRANSGENDERFEMALE: return "transgender-female";
            case TRANSGENDERMALE: return "transgender-male";
            case NONBINARY: return "non-binary";
            case MALE: return "male";
            case FEMALE: return "female";
            case OTHER: return "other";
            case NONDISCLOSE: return "non-disclose";
            default: return "?";
          }
        }
        public String getSystem() {
          return "http://hl7.org/fhir/gender-identity";
        }
        public String getDefinition() {
          switch (this) {
            case TRANSGENDERFEMALE: return "the patient identifies as transgender male-to-female";
            case TRANSGENDERMALE: return "the patient identifies as transgender female-to-male";
            case NONBINARY: return "the patient identifies with neither/both female and male";
            case MALE: return "the patient identifies as male";
            case FEMALE: return "the patient identifies as female";
            case OTHER: return "other gender identity";
            case NONDISCLOSE: return "the patient does not wish to disclose his gender identity";
            default: return "?";
          }
        }
        public String getDisplay() {
          switch (this) {
            case TRANSGENDERFEMALE: return "transgender female";
            case TRANSGENDERMALE: return "transgender male";
            case NONBINARY: return "non-binary";
            case MALE: return "male";
            case FEMALE: return "female";
            case OTHER: return "other";
            case NONDISCLOSE: return "does not wish to disclose";
            default: return "?";
          }
    }


}
